<?php
/**
 * FAQ Woocommerce Admin Settings
 *
 * @class    FAQ_Woocommerce_Settings
 * @package  FAQ_Woocommerce\Admin\Setting
 * @version  1.0.0
 *
 * @link    https://wpfeel.net/
 * @since   1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * FAQ_Woocommerce_Settings class.
 */
class FAQ_Woocommerce_Settings {
    /* Saved options */
    public $options;

    /**
     * Constructor.
     */
    public function __construct() {
        add_action( 'admin_menu', array( $this, 'ffw_add_admin_menu' ) );
        add_action( 'admin_init', array( $this, 'ffw_settings_init' ) );

        // Get registered option
        $this->options = get_option( 'ffw_general_settings' );
    }

	/**
	 * Menu Page.
	 */
    public function ffw_add_admin_menu() {
		add_submenu_page( 'woocommerce', 'FAQ for Woocommerce', 'FAQs', 'manage_options', 'woocommerce-faq', array( $this, 'ffw_options_page' ), 9999 );
    }

	/**
	 * Settings Init.
	 */
    public function ffw_settings_init() {
        register_setting( 'ffw_settings', 'ffw_general_settings' );
        add_settings_section(
            'ffw_general_setting',
            __( '', 'faq-for-woocommerce' ),
            '',
            'ffw_settings'
        );

        add_settings_field(
            'ffw_disable_schema',
            __( 'Enable/Disable Schema', 'faq-for-woocommerce' ),
            array( $this, 'ffw_disable_schema' ),
            'ffw_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_before_faq',
            __( 'Before FAQ', 'faq-for-woocommerce' ),
            array( $this, 'ffw_before_faq_render' ),
            'ffw_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_layout',
            __( 'Layout', 'faq-for-woocommerce' ),
            array( $this, 'ffw_select_field_1_render' ),
            'ffw_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_after_faq',
            __( 'After FAQ', 'faq-for-woocommerce' ),
            array( $this, 'ffw_after_faq_render' ),
            'ffw_settings',
            'ffw_general_setting'
        );


        register_setting( 'ffw_style_settings', 'ffw_general_settings' );
        add_settings_section(
            'ffw_general_setting',
            __( '', 'faq-for-woocommerce' ),
            '',
            'ffw_style_settings'
        );

        add_settings_field(
            'ffw_custom_css',
            __( 'Custom CSS', 'faq-for-woocommerce' ),
            array( $this, 'ffw_custom_css_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_question_text_color',
            __( 'Question Text Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_question_text_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_question_bg_color',
            __( 'Question Background Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_question_bg_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_question_bg_secondary_color',
            __( 'Question Background Secondary Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_question_bg_secondary_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_question_border_color',
            __( 'Question Border Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_question_border_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_question_font_size',
            __( 'Question Font Size', 'faq-for-woocommerce' ),
            array( $this, 'ffw_question_font_size_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

//        add_settings_field(
//            'ffw_answer_text_color',
//            __( 'Answer Text Color', 'faq-for-woocommerce' ),
//            array( $this, 'ffw_answer_text_color_field' ),
//            'ffw_style_settings',
//            'ffw_general_setting'
//        );

        add_settings_field(
            'ffw_answer_bg_color',
            __( 'Answer Background Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_answer_bg_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

        add_settings_field(
            'ffw_answer_border_color',
            __( 'Answer Border Color', 'faq-for-woocommerce' ),
            array( $this, 'ffw_answer_border_color_field' ),
            'ffw_style_settings',
            'ffw_general_setting'
        );

//        add_settings_field(
//            'ffw_answer_font_size',
//            __( 'Answer Font Size', 'faq-for-woocommerce' ),
//            array( $this, 'ffw_answer_font_size_field' ),
//            'ffw_style_settings',
//            'ffw_general_setting'
//        );
    }

    /**
     * Enable/Disable FAQ Schema.
     *
     * @since 1.2.2
     * @return
     */
    function ffw_disable_schema( ) {
        $options        = get_option( 'ffw_general_settings' );
        $options        = ! empty( $options ) ? $options : [];
        $disable_schema = array_key_exists( 'ffw_disable_schema', $options ) && ! empty($options['ffw_disable_schema']) ? $options['ffw_disable_schema'] : '';
        ?>
        <select class="widefat ffw-schema-enable-disable" name='ffw_general_settings[ffw_disable_schema]'>
            <option value="1" <?php selected( $disable_schema, 1 ); ?>>Enable</option>
            <option value="2" <?php selected( $disable_schema, 2 ); ?>>Disable</option>
        </select>
        <?php
    }

	/**
	 * Before FAQ Callback.
	 */
    function ffw_before_faq_render( ) {
        $options = get_option( 'ffw_general_settings' );
		$options = ! empty( $options ) ? $options : [];
		$before_faq = array_key_exists( 'ffw_before_faq', $options ) && ! empty($options['ffw_before_faq']) ? $options['ffw_before_faq'] : '';

		$settings  = array(
			'media_buttons' => true,
			'textarea_name' => 'ffw_general_settings[ffw_before_faq]',
		);
        wp_editor( $before_faq, 'ffw_before_faq_html', $settings );
        ?>
        <?php
    }

	/**
	 * Layout options.
	 */
    function ffw_select_field_1_render() {
        $options = get_option( 'ffw_general_settings' );
		$options = ! empty( $options ) ? $options : [];
		$layout = isset( $options['ffw_layout'] ) ? $options['ffw_layout'] : 1;

        ?>
        <select class="widefat ffw-layout-select" name='ffw_general_settings[ffw_layout]'>
            <option value="1" <?php selected( $layout, 1 ); ?>>Classic</option>
            <option value="2" <?php selected( $layout, 2 ); ?>>Whitish</option>
            <option value="3" <?php selected( $layout, 3 ); ?>>Trip</option>
            <option value="4" <?php selected( $layout, 4 ); ?>>Pop</option>
        </select>
        <?php
    }

	/**
	 * After FAQ Callback.
	 */
    function ffw_after_faq_render() {
        $options = get_option( 'ffw_general_settings' );
		$options = ! empty( $options ) ? $options : [];

		$after_faq = array_key_exists( 'ffw_after_faq', $options ) && ! empty($options['ffw_after_faq']) ? $options['ffw_after_faq'] : '';
		$settings  = array(
			'media_buttons' => true,
			'textarea_name' => 'ffw_general_settings[ffw_after_faq]',
		);
		wp_editor( $after_faq, 'ffw_after_faq_html', $settings );
    }

	/**
	 * Setting Description Callback.
	 */
    function ffw_settings_section_callback() {
        _e( '<p>This is where you can set faq options.The following options affect the faqs are displayed on the frontend.</p>', 'faq-for-woocommerce' );
    }

    /**
     * Custom CSS Callback.
     */
    function ffw_custom_css_field() {
        $val = ( isset( $this->options['ffw_custom_css'] ) ) ? $this->options['ffw_custom_css'] : '';
        echo '<textarea class="ffw-custom-css" name="ffw_general_settings[ffw_custom_css]" >'. $val .'</textarea>';
    }

    /**
     * Question Text Color Callback.
     */
    function ffw_question_text_color_field() {
        $val = ( isset( $this->options['ffw_question_text_color'] ) ) ? $this->options['ffw_question_text_color'] : '';
        echo '<input type="text" class="ffw_question_text_color" name="ffw_general_settings[ffw_question_text_color]" value="' . $val . '" />';
    }

    /**
     * Question Background Color Callback.
     */
    function ffw_question_bg_color_field() {
        $val = ( isset( $this->options['ffw_question_bg_color'] ) ) ? $this->options['ffw_question_bg_color'] : '';
        echo '<input type="text" class="ffw_question_bg_color" name="ffw_general_settings[ffw_question_bg_color]" value="' . $val . '" />';
    }

    /**
     * Question Background Secondary Color Callback.
     */
    function ffw_question_bg_secondary_color_field() {
        $val = ( isset( $this->options['ffw_question_bg_secondary_color'] ) ) ? $this->options['ffw_question_bg_secondary_color'] : '';
        echo '<input type="text" class="ffw_question_bg_secondary_color" name="ffw_general_settings[ffw_question_bg_secondary_color]" value="' . $val . '" />';
    }

    /**
     * Question Border Color Callback.
     */
    function ffw_question_border_color_field() {
        $val = ( isset( $this->options['ffw_question_border_color'] ) ) ? $this->options['ffw_question_border_color'] : '';
        echo '<input type="text" class="ffw_question_border_color" name="ffw_general_settings[ffw_question_border_color]" value="' . $val . '" />';
    }

    /**
     * Question Font Size Callback.
     */
    function ffw_question_font_size_field() {
        $val = ( isset( $this->options['ffw_question_font_size'] ) ) ? $this->options['ffw_question_font_size'] : '';
        echo '<input type="range" class="ffw_question_font_size" name="ffw_general_settings[ffw_question_font_size]" min="0" max="50" step="1" value="' . $val . '" />';
        echo sprintf('<span class="ffw_question_font_size_label">%s</span>', esc_html__($val . 'px', 'faq-for-woocommerce') );
    }

    /**
     * Answer Text Color Callback.
     */
    function ffw_answer_text_color_field() {
        $val = ( isset( $this->options['ffw_answer_text_color'] ) ) ? $this->options['ffw_answer_text_color'] : '';
        echo '<input type="text" class="ffw_answer_text_color" name="ffw_general_settings[ffw_answer_text_color]" value="' . $val . '" />';
    }

    /**
     * Answer Background Color Callback.
     */
    function ffw_answer_bg_color_field() {
        $val = ( isset( $this->options['ffw_answer_bg_color'] ) ) ? $this->options['ffw_answer_bg_color'] : '';
        echo '<input type="text" class="ffw_answer_bg_color" name="ffw_general_settings[ffw_answer_bg_color]" value="' . $val . '" />';
    }

    /**
     * Answer Border Color Callback.
     */
    function ffw_answer_border_color_field() {
        $val = ( isset( $this->options['ffw_answer_border_color'] ) ) ? $this->options['ffw_answer_border_color'] : '';
        echo '<input type="text" class="ffw_answer_border_color" name="ffw_general_settings[ffw_answer_border_color]" value="' . $val . '" />';
    }

    /**
     * Answer Font Size Callback.
     */
    function ffw_answer_font_size_field() {
        $val = ( isset( $this->options['ffw_answer_font_size'] ) ) ? $this->options['ffw_answer_font_size'] : '';
        echo '<input type="range" class="ffw_answer_font_size" name="ffw_general_settings[ffw_answer_font_size]" min="0" max="50" step="1" value="' . $val . '" />';
        echo sprintf('<span class="ffw_answer_font_size_label">%s</span>', esc_html__($val . 'px', 'faq-for-woocommerce') );
    }

    /**
	 * Options Page HTML.
	 */
    function ffw_options_page() {
        ?>
        <div class="wrap ffw-setting-wrap">
            <form action='options.php' method='post'>
                <?php
                    echo sprintf('<h1>%s</h1>', esc_html__( "FAQ For WooCommerce", "faq-for-woocommerce" ) );
                    _e( '<p>This is where you can set faq options.The following options affect the faqs are displayed on the frontend.</p>', 'faq-for-woocommerce' );
                ?>
                <?php $this->ffw_nav_items(); ?>
                <div class="tab-content">
                    <div class="tab-pane active" id="ffw-general">
                        <div class="ffw-setting-wrapper">
                            <div class="ffw-setting-form">
                                <?php
                                    settings_fields( 'ffw_settings' );
                                    do_settings_sections( 'ffw_settings' );
                                ?>
                            </div>

                            <div class="ffw-setting-layout" id="ffw-preview">
                                <?php
                                    echo sprintf( '<h3 class="ffw-preview-title">%s</h3>', esc_html__('Preview', 'faq-for-woocommerce') );

                                    //get layout
                                    $options = get_option( 'ffw_general_settings' );
                                    $layout = isset( $options['ffw_layout'] ) ? (int) $options['ffw_layout'] : 1;

                                    //preview images url
                                    $classic_image_url  = FFW_PLUGIN_URL . '/assets/admin/images/classic.svg';
                                    $whitish_image_url  = FFW_PLUGIN_URL . '/assets/admin/images/whitish.svg';
                                    $trip_image_url     = FFW_PLUGIN_URL . '/assets/admin/images/trip.svg';
                                    $pop_image_url      = FFW_PLUGIN_URL . '/assets/admin/images/pop.svg';

                                ?>

                                <img data-layout="1" class="<?php echo 1 === $layout ? esc_attr('ffw-visible') : 'ffw-hide'; ?>"  src="<?php echo esc_attr( $classic_image_url ); ?>" alt="Faq Classic Layout">
                                <img data-layout="2" class="<?php echo 2 === $layout ? esc_attr('ffw-visible') : 'ffw-hide'; ?>" src="<?php echo esc_attr( $whitish_image_url ); ?>" alt="Faq Whitish Layout">
                                <img data-layout="3" class="<?php echo 3 === $layout ? esc_attr('ffw-visible') : 'ffw-hide'; ?>"  src="<?php echo esc_attr( $trip_image_url ); ?>" alt="Faq Trip Layout">
                                <img data-layout="4" class="<?php echo 4 === $layout ? esc_attr('ffw-visible') : 'ffw-hide'; ?>"  src="<?php echo esc_attr( $pop_image_url ); ?>" alt="Faq Pop Layout">
                            </div>
                        </div>
                    </div>
                    <div class="tab-pane" id="ffw-style">
                        <?php
                            settings_fields( 'ffw_style_settings' );
                            do_settings_sections( 'ffw_style_settings' );
                        ?>
                    </div>
                    <div class="tab-pane" id="ffw-help">
                        <h1>FAQ Help</h1>
                    </div>
                </div>

                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    /**
     * Setting Page Nav Items.
     */
    function ffw_nav_items() {

        //setting options class initialize
        $tabs = $this->ffw_get_options_tabs();
        ?>
            <nav>
                <div class="nav nav-tabs nav-tab-wrapper wflg-nav-tab-wrapper" id="nav-tab" role="tablist">
                    <?php
                    foreach ($tabs as $tab) {
                        ?>
                        <a href="#<?php echo $tab['slug']; ?>" class="<?php echo ffw_array_separator(' ', $tab['class']); ?>"
                           data-toggle="tab" role="tab" aria-selected="true"><?php echo $tab['title']; ?></a>
                        <?php
                    }
                    ?>
                </div>
            </nav>
        <?php
    }

    /**
     * Get setting tab items.
     *
     * @since  1.1.8
     * @return array
     */
    function ffw_get_options_tabs() {
        $settings = array(
            array(
                'title' => __( 'General', 'faq-for-woocommerce' ),
                'slug' => 'ffw-general',
                'class' => array('nav-item','nav-link', 'active')
            ),
            array(
                'title' => __( 'Style', 'faq-for-woocommerce' ),
                'slug' => 'ffw-style',
                'class' => array('nav-item', 'nav-link')
            )
        );

        return apply_filters('ffw_options_tabs', $settings);
    }
}

new FAQ_Woocommerce_Settings();


