<?php
if ( ! function_exists( 'ffw_check_woocommerce' ) ) {
	function ffw_check_woocommerce() {
		return class_exists( 'WooCommerce', false );
	}
}

if ( ! function_exists( 'ffw_is_WC_supported' ) ) {
	function ffw_is_WC_supported() {
		// Ensure WC is loaded before checking version
		return ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, FFW_MIN_WC_VERSION, '>=' ) );
	}
}

/*
 * Tab
 */
add_filter('woocommerce_product_data_tabs', 'ffw_product_settings_tabs' );
function ffw_product_settings_tabs( $tabs ) {
	$tabs['faq_for_woocommerce'] = array(
		'label'    => 'FAQs',
		'target'   => 'ffw_product_data',
		'priority' => 100,
	);
	
	return $tabs;
}


/*
 * Tab content
 */
add_action( 'woocommerce_product_data_panels', 'ffw_product_panels' );
function ffw_product_panels() {
	$product_faqs_data = [];

    //faqs list
	if ( isset($_GET['post']) && ! empty($_GET['post']) ) {
		$post_id = sanitize_text_field( wp_unslash($_GET['post']) );
		$product_faqs = get_product_faqs($post_id);
		$product_faqs_data = htmlspecialchars(json_encode($product_faqs));
	}
	?>
	<div id="ffw_product_data" class="panel ffw_options_panel woocommerce_options_panel hidden">
		<?php include FFW_FILE_DIR . '/views/faq-woocommerce-modal-form.php'; ?>
        <div class="ffw-product-loader">
            <div class="ffw-product-loader-overlay">
                <span class="spinner is-active"></span>
            </div>
        </div>
		<div class="ffw-product-form-header" id="ffw-product-form-header">
			<?php do_action( 'before_faq_woocommerce_product_options' ); ?>
			<div class="ffw-sortable-options-wrapper">
				<div class="ffw-sortable-options-header">
					<?php echo sprintf('<h3 class="ffw-option-header-title">%s</h3>', esc_html__('FAQ List', 'faq-for-woocommerce')); ?>
					<div class="ffw-option-buttons">
                        <?php echo sprintf('<button class="ffw-add-new ffw-options-header-btn">%s</button>', esc_html__('Add New', 'faq-for-woocommerce')); ?>
                        <?php echo sprintf('<button class="ffw-delete-all ffw-options-header-btn" id="ffw-delete-all-faq">%s</button>', esc_html__('Delete All', 'faq-for-woocommerce')); ?>
					</div>
                    <input type="hidden" id="ffw_products" value="<?php echo $product_faqs_data; ?>">
                    <input type="hidden" id="ffw_product_page_id" value="<?php echo isset($_GET['post']) ? sanitize_text_field( wp_unslash($_GET['post']) ) : ''; ?>">
				</div>
                <div class="ffw-sortable-options-body ffw-metaboxes-wrapper">
                    <?php
                        if ( $product_faqs ) {
                            foreach ( $product_faqs as $faq_item ) {
                                ?>
                                <div class="ffw-metabox-item ffw-metabox closed" data-id="<?php echo esc_attr(absint( $faq_item['id'] )) + 1; ?>">
                                    <h3>
                                        <a href="#" class="ffw-single-delete-btn ffw-meta-btn" rel="<?php echo esc_attr(absint( $faq_item['id'] )) + 1; ?>">Remove</a>
                                        <a href="#" class="ffw-single-edit-btn ffw-meta-btn" rel="<?php echo esc_attr(absint( $faq_item['id'] )) + 1; ?>">Edit</a>
                                        <div class="ffw-handle-item" aria-label="Click to toggle"></div>
                                        <?php
                                            echo sprintf('<strong>%s</strong>', esc_html__($faq_item['question'], 'faq-for-woocommerce') );
                                        ?>
                                    </h3>
                                    <div class="ffw-metabox-content" style="display: none;">
                                        <div class="data">
											<?php
											echo sprintf('<div>%s</div>', __($faq_item['answer'], 'faq-for-woocommerce') );
											?>
                                        </div>
                                    </div>
                                </div>
                                <?php
                            }
                        }
                    ?>
                </div>
			</div>

			<?php do_action( 'after_faq_woocommerce_product_options' ); ?>
		</div>
	</div>
	<?php
}

if ( ! function_exists( 'ffw_insert_new_faq' ) ) {
	add_action( 'wp_ajax_ffw_insert_new_faq', 'ffw_insert_new_faq' );
	/**
	 * Insert FAQ
     *
     * @since 1.0.0
	 */
	function ffw_insert_new_faq() {
		//check_ajax_referer( 'ffw_admin' );

		if ( ! isset( $_REQUEST['faq_data'] ) ) {
			wp_send_json_error( esc_html__( 'Invalid Request.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		if ( ! isset( $_REQUEST['faq_data']['product_id'] ) ) {
			wp_send_json_error( esc_html__( 'Not in Edit page.', 'faq-for-woocommerce' ) );
			wp_die();
        }

		if ( ! isset( $_REQUEST['faq_data']['faq_list'] ) ) {
			wp_send_json_error( esc_html__( 'Empty FAQ List.', 'faq-for-woocommerce' ) );
			wp_die();
        }

		$product_id = (int) sanitize_text_field( wp_unslash($_REQUEST['faq_data']['product_id'] ));

		//update faq list
		$updated = update_post_meta( $product_id, 'ffw_faqs_list', wp_unslash($_REQUEST['faq_data']['faq_list']) );

		if ( $updated ) {
		    $msg = esc_html__('Update Successfull!', 'faq-for-woocommerce');
        }else {
			$msg = esc_html__('Something Wrong!', 'faq-for-woocommerce');
        }

		ob_start();
		?>
        <div class="ffw-metabox-item ffw-metabox closed" data-id="<?php echo isset($_REQUEST['faq_data']['id']) ? esc_attr(absint($_REQUEST['faq_data']['id'])) + 1 : 0; ?>">
            <h3>
                <a href="#" class="ffw-single-delete-btn ffw-meta-btn" rel="<?php echo isset($_REQUEST['faq_data']['id']) ? esc_attr(absint($_REQUEST['faq_data']['id'])) + 1 : 0; ?>">Remove</a>
                <a href="#" class="ffw-single-edit-btn ffw-meta-btn" rel="<?php echo isset($_REQUEST['faq_data']['id']) ? esc_attr(absint($_REQUEST['faq_data']['id'])) + 1 : 0; ?>">Edit</a>
                <div class="ffw-handle-item" aria-label="Click to toggle"></div>
				<?php
                if ( isset($_REQUEST['faq_data']['question']) ) {
				    echo sprintf('<strong>%s</strong>', esc_html__( sanitize_text_field( wp_unslash( $_REQUEST['faq_data']['question'] ) ), 'faq-for-woocommerce') );
                }
				?>
            </h3>
            <div class="ffw-metabox-content" style="display: none;">
                <div class="data">
					<?php
                    if ( isset($_REQUEST['faq_data']['answer']) ) {
					    echo sprintf('<div>%s</div>', __( wp_unslash( $_REQUEST['faq_data']['answer'] ), 'faq-for-woocommerce') );
                    }
					?>
                </div>
            </div>
        </div>

        <?php
        $new_faq = ob_get_clean();

		if ( $updated ) {
            wp_send_json_success(
                [
                    'faq'      => $new_faq,
                    'faq_data' => sanitize_text_field( wp_unslash( $_REQUEST['faq_data']['faq_list'] ) ),
                    'message'  => $msg,
                    'success'  => false,
                    'product_id'  => $product_id,
                ], 200
            );
            wp_die();
        } else {
            wp_send_json_error(
                [
                    'message' => esc_html__( 'No faq added.', 'faq-for-woocommerce' ),
                    'success' => false,
                ]
            );
            wp_die();
		}
	}
}

if ( ! function_exists( 'ffw_update_faq' ) ) {
	add_action( 'wp_ajax_ffw_update_faq', 'ffw_update_faq' );
	/**
	 * Update FAQ
     *
     * @since 1.0.2
	 */
	function ffw_update_faq() {
		//check_ajax_referer( 'ffw_admin' );

		if ( ! isset( $_REQUEST['faq_update_data'] ) ) {
			wp_send_json_error( esc_html__( 'Invalid Request.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		if ( ! isset( $_REQUEST['faq_update_data']['product_id'] ) ) {
			wp_send_json_error( esc_html__( 'Not in Edit page.', 'faq-for-woocommerce' ) );
			wp_die();
        }

		if ( ! isset( $_REQUEST['faq_update_data']['faq_list'] ) ) {
			wp_send_json_error( esc_html__( 'Empty FAQ List.', 'faq-for-woocommerce' ) );
			wp_die();
        }

		$product_id = (int) sanitize_text_field( wp_unslash($_REQUEST['faq_update_data']['product_id'] ));

		//update faq list
		$updated = update_post_meta( $product_id, 'ffw_faqs_list', wp_unslash($_REQUEST['faq_update_data']['faq_list']) );

		if ( $updated ) {
		    $msg = esc_html__('Update Successfull!', 'faq-for-woocommerce');
        }else {
			$msg = esc_html__('Something Wrong!', 'faq-for-woocommerce');
        }

		ob_start();
		?>
        <div class="ffw-metabox-item ffw-metabox closed" data-id="<?php echo isset($_REQUEST['faq_update_data']['id']) ? esc_attr(absint($_REQUEST['faq_update_data']['id'])) + 1 : 0; ?>">
            <h3>
                <a href="#" class="ffw-single-delete-btn ffw-meta-btn" rel="<?php echo isset($_REQUEST['faq_update_data']['id']) ? esc_attr(absint($_REQUEST['faq_update_data']['id'])) + 1 : 0; ?>">Remove</a>
                <a href="#" class="ffw-single-edit-btn ffw-meta-btn" rel="<?php echo isset($_REQUEST['faq_update_data']['id']) ? esc_attr(absint($_REQUEST['faq_update_data']['id'])) + 1 : 0; ?>">Edit</a>
                <div class="ffw-handle-item" aria-label="Click to toggle"></div>
				<?php
                if ( isset($_REQUEST['faq_update_data']['question']) ) {
				    echo sprintf('<strong>%s</strong>', esc_html__( sanitize_text_field( wp_unslash( $_REQUEST['faq_update_data']['question'] ) ), 'faq-for-woocommerce') );
                }
				?>
            </h3>
            <div class="ffw-metabox-content" style="display: none;">
                <div class="data">
					<?php
                    if ( isset($_REQUEST['faq_update_data']['answer']) ) {
					    echo sprintf('<div>%s</div>', __( sanitize_text_field( wp_unslash( $_REQUEST['faq_update_data']['answer'] ) ), 'faq-for-woocommerce') );
                    }
					?>
                </div>
            </div>
        </div>

        <?php
        $updated_faq_html = ob_get_clean();

		if ( $updated ) {
            wp_send_json_success(
                [
                    'faq'      => $updated_faq_html,
                    'faq_data' => sanitize_text_field( wp_unslash( $_REQUEST['faq_update_data']['faq_list'] ) ),
                    'message'  => $msg,
                    'success'  => false,
                    'product_id'  => $product_id,
                ], 200
            );
            wp_die();
        } else {
            wp_send_json_error(
                [
                    'message' => esc_html__( 'No faq added.', 'faq-for-woocommerce' ),
                    'success' => false,
                ]
            );
            wp_die();
		}
	}
}


if ( ! function_exists( 'ffw_delete_all_faqs' ) ) {
	add_action( 'wp_ajax_ffw_delete_all_faqs', 'ffw_delete_all_faqs' );
	/**
	 * Delete All FAQ
     *
     * @since 1.0.0
	 */
	function ffw_delete_all_faqs() {
		//check_ajax_referer( 'ffw_admin' );

		if ( ! isset( $_REQUEST['faq_delete_data'] ) ) {
			wp_send_json_error( esc_html__( 'Invalid Request.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		if ( ! isset( $_REQUEST['faq_delete_data']['product_id'] ) ) {
			wp_send_json_error( esc_html__( 'Not in Edit page.', 'faq-for-woocommerce' ) );
			wp_die();
        }

		$product_id = (int) sanitize_text_field( wp_unslash( $_REQUEST['faq_delete_data']['product_id'] ) );

		//deleted all faq list
		$deleted = delete_post_meta( $product_id, 'ffw_faqs_list' );

		if ( $deleted ) {
		    $msg = esc_html__('Deleted All FAQ Successfull!', 'faq-for-woocommerce');
        }else {
			$msg = esc_html__('Something Wrong!', 'faq-for-woocommerce');
        }


		if ( $deleted ) {
            wp_send_json_success(
                [
                    'message' => $msg,
                    'success' => true,
                ], 200
            );
            wp_die();

        } else {
            wp_send_json_error(
                [
                    'message' => esc_html__( 'No faq deleted.', 'faq-for-woocommerce' ),
                    'success' => false,
                ]
            );
            wp_die();
		}
	}
}



if ( ! function_exists( 'ffw_delete_single_faq' ) ) {
	add_action( 'wp_ajax_ffw_delete_single_faq', 'ffw_delete_single_faq' );
	/**
	 * Delete Single FAQ
	 *
	 * @since 1.0.0
	 */
	function ffw_delete_single_faq() {
		//check_ajax_referer( 'ffw_admin' );

		if ( ! isset( $_REQUEST['faq_updated_data'] ) ) {
			wp_send_json_error( esc_html__( 'Invalid Request.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		if ( ! isset( $_REQUEST['faq_updated_data']['product_id'] ) ) {
			wp_send_json_error( esc_html__( 'Not in Edit page.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		if ( ! isset( $_REQUEST['faq_updated_data']['updated_faq_list'] ) ) {
			wp_send_json_error( esc_html__( 'Empty FAQ List.', 'faq-for-woocommerce' ) );
			wp_die();
		}

		$product_id = (int) sanitize_text_field( wp_unslash($_REQUEST['faq_updated_data']['product_id'] ) );

		//delete current faq and update faq list
		$updated = update_post_meta( $product_id, 'ffw_faqs_list', wp_unslash( $_REQUEST['faq_updated_data']['updated_faq_list'] ) );

		if ( $updated ) {
			$msg = esc_html__('Update Successfull!', 'faq-for-woocommerce');
			wp_send_json_success(
				[
					'message' => $msg,
					'success' => false,
				], 200
			);
			wp_die();
		}else {
			$msg = esc_html__('Something Wrong!', 'faq-for-woocommerce');
			wp_send_json_error(
				[
					'message' => esc_html__( 'No faq deleted.', 'faq-for-woocommerce' ),
					'success' => false,
				]
			);
			wp_die();
		}
	}
}

