<?php
/**
 * FAQ Woocommerce Schema
 *
 * @class    FAQ_Woocommerce_Schema
 * @package  FAQ_Woocommerce\Schema
 * @version  1.2.2
 *
 * @link    https://wpfeel.net/
 * @since   1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * FAQ_Woocommerce_Schema class.
 */
class FAQ_Woocommerce_Schema {
    /**
     * Faq list.
     *
     * @var array
     */
    protected $faqs = array();

    /**
     * Schema Enable/Disable.
     *
     * @var mixed
     */
    protected $schema_enable = true;

    /**
     * Constructor.
     */
    public function __construct() {
        $this->schema_enable = $this->get_schema_setting();
        add_action( 'wp_head', array( $this, 'display_schema' ) );
    }

    /**
     * Include any classes we need within admin.
     */
    public function includes() {
        //Setting page
        //include_once dirname( __FILE__ ) . '/class-faq-woocommerce-settings.php';
    }

    /**
     * Get schema setting.
     *
     * @return boolean
     */
    public function get_schema_setting() {
        $options        = get_option( 'ffw_general_settings' );
        $options        = ! empty( $options ) ? $options : [];
        $enable_schema  = array_key_exists( 'ffw_disable_schema', $options ) && ! empty($options['ffw_disable_schema']) ? (int) $options['ffw_disable_schema'] : '';

        return isset($enable_schema) && 1 === $enable_schema ? true : false;
    }

    /**
     * Display FAQ
     */
    public function display_schema() {
        if( $this->schema_enable && is_product() ) {
            global $post;
            $product_id = $post->ID;
            $faqs = get_product_faqs($product_id);
            $faq_lists = [];
            $single_schema_data = [];
            if( sizeof($faqs) > 0 ) {
                foreach ($faqs as $key => $faq_list) {
                    foreach( $faq_list as $faq_key => $faq_value ) {
                        $single_schema_data['@type'] = 'Question';
                        if( 'question' === $faq_key ) {
                            $single_schema_data['name'] = $faq_value;
                        }
                        $single_schema_data['acceptedAnswer']['@type'] = 'Answer';
                        if( 'answer' === $faq_key ) {
                            $single_schema_data['acceptedAnswer']['text'] = $faq_value;
                        }
                    }
                    array_push($faq_lists, $single_schema_data);
                }
            }
            ?>
            <!-- faq schema by FAQ for Woocommerce -->
            <script type="application/ld+json">
                {
                    "@context": "https://schema.org",
                    "@type": "FAQPage",
                    "mainEntity": <?php echo json_encode($faq_lists, JSON_PRETTY_PRINT); ?>
                }
            </script>
            <?php
        }
    }

}

return new FAQ_Woocommerce_Schema();
