<?php
function get_product_faqs( $product_id ) {
	if ( isset($product_id) && ! empty($product_id) ) {
		$faq_lists = get_post_meta($product_id, 'ffw_faqs_list', true);
		$faq_lists = ! empty($faq_lists) && is_array($faq_lists) ? $faq_lists : [];

		return apply_filters('ffw_get_product_faqs', $faq_lists);
	}
}

/**
 * Shortcode to show template.
 *
 * @param string $atts mixed.
 *
 * @return void
 * @since  1.1.3
 *
 */
if ( ! function_exists('ffw_show_template_shortcode') ) {
	function ffw_show_template_shortcode( $atts ) {
		$rand_product_id = ffw_get_random_product_id_has_faq();
		$atts = shortcode_atts( array(
			'template' => 1,
			'id' => $rand_product_id,
		), $atts, 'ffw_template' );

		$template = (int) $atts['template'];
		$product_id = (int) $atts['id'];

		return ffw_get_template($template, $product_id, true);
	}
}
add_shortcode('ffw_template', 'ffw_show_template_shortcode');

/**
 * Get template to show in front.
 *
 * @param int $layout template number
 * @param int $id product id
 *
 * @return void
 * @since  1.1.3
 *
 */
if ( ! function_exists('ffw_get_template') ) {
	function ffw_get_template( $layout, $id, $is_shortcode = false ) {
		$content = '';
		$faqs = get_product_faqs($id);
		$shortcode_wrap_class = $is_shortcode ? 'ffw-main-wrapper-shortcode' : '';

		// enqueue template CSS.
		if ( 1 === $layout ) {
			wp_enqueue_style( 'ffw_classic_styles' );
		}elseif ( 2 === $layout ) {
			wp_enqueue_style( 'ffw_whitish_styles' );
		}elseif ( 3 === $layout ) {
			wp_enqueue_style( 'ffw_trip_styles' );
		}elseif ( 4 === $layout ) {
			wp_enqueue_style( 'ffw_pop_styles' );
		}

		ob_start();

		$content .= '<div class="ffw-main-wrapper '. esc_attr($shortcode_wrap_class) .'" id="ffw-main-wrapper">';

		do_action('ffw_before_faq_start');

		//get faq templates
		if ( 1 === $layout || 2 === $layout ) {
			include FFW_FILE_DIR . '/views/ffw-classic-template.php';
		} elseif ( 3 === $layout ) {
			include FFW_FILE_DIR . '/views/ffw-trip-template.php';
		} elseif ( 4 === $layout ) {
			include FFW_FILE_DIR . '/views/ffw-pop-template.php';
		}

		echo '<br>';

		do_action('ffw_after_faq_end');

		$content .= ob_get_clean();

		return $content . '</div>';
	}
}

/**
 * Get random product id which has faq list.
 *
 * @return int
 * @since  1.1.3
 */
if ( ! function_exists('ffw_get_random_product_id_has_faq') ) {
	function ffw_get_random_product_id_has_faq() {
		$args = array(
			'post_type' => 'product',
			'posts_per_page' => 1,
			'fields' => 'ids',
			'meta_query' => array(
				array(
					'key' => 'ffw_faqs_list',
					'value' => '',
					'compare' => '!=',
				),
			),
			'orderby' => 'rand',
			'order' => 'ASC',
		);

		$product_ids = get_posts($args);

		return reset($product_ids);
	}
}

/**
 * Array to string separator
 *
 * @param string $separator - the separator to separate array items
 * @param array $array - array to slice and make string with separator
 *
 * @return string|boolean
 */
function ffw_array_separator( string $separator, array $array ) {

    return is_array( $array ) ? implode( $separator, $array ) : false;

}